@@ -20,14 +20,18 @@ from __future__ import division
 from __future__ import unicode_literals
 
 from googlecloudsdk.calliope.concepts import concepts
+from googlecloudsdk.calliope.concepts import deps
 from googlecloudsdk.command_lib.util.concepts import concept_parsers
 from googlecloudsdk.command_lib.util.concepts import presentation_specs
+from googlecloudsdk.core import properties
 
 
 def LocationAttributeConfig():
+  fts = [deps.PropertyFallthrough(properties.VALUES.batch.location)]
   return concepts.ResourceParameterAttributeConfig(
       name='location',
-      help_text='Google Cloud location for the {resource}.')
+      help_text='Google Cloud location for the {resource}.',
+      fallthroughs=fts)
 
 
 def JobAttributeConfig():
@@ -65,16 +69,6 @@ def GetJobResourceSpec():
       projectsId=concepts.DEFAULT_PROJECT_ATTRIBUTE_CONFIG)
 
 
-def GetTaskGroupResourceSpec():
-  return concepts.ResourceSpec(
-      'batch.projects.locations.jobs.taskGroups',
-      resource_name='task_group',
-      taskGroupsId=TaskGroupAttributeConfig(),
-      jobsId=JobAttributeConfig(),
-      locationsId=LocationAttributeConfig(),
-      projectsId=concepts.DEFAULT_PROJECT_ATTRIBUTE_CONFIG)
-
-
 def GetTaskResourceSpec():
   return concepts.ResourceSpec(
       'batch.projects.locations.jobs.taskGroups.tasks',
@@ -96,16 +90,37 @@ def AddLocationResourceArgs(parser):
       presentation_specs.ResourcePresentationSpec(
           '--location',
           GetLocationResourceSpec(),
-          'The Batch location resource.',
+          ('The Batch location resource. If you omit this flag, the default'
+           'location is used if you set the batch/location property.'
+           'Otherwise, omitting this flag lists jobs across all locations.'),
           required=False,
-          ),
+      ),
+  ]
+
+  concept_parsers.ConceptParser(arg_specs).AddToParser(parser)
+
+
+def AddJobFlagResourceArgs(parser):
+  """Add the job resource argument as flag.
+
+  Args:
+    parser: the parser for the command.
+  """
+  arg_specs = [
+      presentation_specs.ResourcePresentationSpec(
+          '--job',
+          GetJobResourceSpec(),
+          ('The Batch job resource. If not specified,'
+           'the current batch/location is used.'),
+          required=True,
+      ),
   ]
 
   concept_parsers.ConceptParser(arg_specs).AddToParser(parser)
 
 
 def AddJobResourceArgs(parser):
-  """Add the job resource argument.
+  """Add the job resource argument as positional.
 
   Args:
     parser: the parser for the command.
@@ -114,27 +129,10 @@ def AddJobResourceArgs(parser):
       presentation_specs.ResourcePresentationSpec(
           'JOB',
           GetJobResourceSpec(),
-          'The Batch job resource.',
+          ('The Batch job resource. If not specified,'
+           'the current batch/location is used.'),
           required=True,
-          ),
-  ]
-
-  concept_parsers.ConceptParser(arg_specs).AddToParser(parser)
-
-
-def AddTaskGroupResourceArgs(parser):
-  """Add the task_group resource argument.
-
-  Args:
-    parser: the parser for the command.
-  """
-  arg_specs = [
-      presentation_specs.ResourcePresentationSpec(
-          'TASK_GROUP',
-          GetTaskGroupResourceSpec(),
-          'The Batch task_group resource.',
-          required=True,
-          ),
+      ),
   ]
 
   concept_parsers.ConceptParser(arg_specs).AddToParser(parser)
@@ -150,9 +148,10 @@ def AddTaskResourceArgs(parser):
       presentation_specs.ResourcePresentationSpec(
           'TASK',
           GetTaskResourceSpec(),
-          'The Batch task resource.',
+          ('The Batch task resource. If not specified,'
+           'the current batch/location is used.'),
           required=True,
-          ),
+      ),
   ]
 
   concept_parsers.ConceptParser(arg_specs).AddToParser(parser)
