@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*- #
-# Copyright 2014 Google Inc. All Rights Reserved.
+# Copyright 2014 Google LLC. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -16,24 +16,27 @@
 """The super-group for the compute CLI."""
 
 from __future__ import absolute_import
+from __future__ import division
 from __future__ import unicode_literals
+
 from googlecloudsdk.api_lib.compute import transforms
 from googlecloudsdk.calliope import base
 
 
 DETAILED_HELP = {
-    'DESCRIPTION': """\
-        The gcloud compute command group lets you create, configure and
-        manipulate Google Compute Engine virtual machines.
+    'DESCRIPTION': """
+        The gcloud compute command group lets you create, configure, and
+        manipulate Compute Engine virtual machine (VM) instances.
 
-        With Compute Engine you can create and run virtual machines
-        on Google infrastructure. Compute Engine offers scale, performance, and
-        value that allows you to easily launch large compute clusters on
+        With Compute Engine, you can create and run VMs
+        on Google's infrastructure. Compute Engine offers scale, performance,
+        and value that lets you launch large compute clusters on
         Google's infrastructure.
 
-        More information on Compute Engine can be found here:
-        https://cloud.google.com/compute/ and detailed documentation can be
-        found here: https://cloud.google.com/compute/docs/
+        For more information about Compute Engine, see the
+        [Compute Engine overview](https://cloud.google.com/compute/)
+        and the
+        [Compute Engine user documentation](https://cloud.google.com/compute/docs/).
         """,
 }
 
@@ -41,13 +44,17 @@ DETAILED_HELP = {
 @base.ReleaseTracks(base.ReleaseTrack.GA, base.ReleaseTrack.BETA,
                     base.ReleaseTrack.ALPHA)
 class Compute(base.Group):
-  """Create and manipulate Google Compute Engine resources."""
+  """Create and manipulate Compute Engine resources."""
   detailed_help = DETAILED_HELP
 
+  category = base.COMPUTE_CATEGORY
+
   @staticmethod
   def Args(parser):
     parser.display_info.AddTransforms(transforms.GetTransforms())
 
   def Filter(self, context, args):
+    # TODO(b/190528962):  Determine if command group works with project number
+    base.RequireProjectID(args)
     del context, args
     base.DisableUserProjectQuota()
