@@ -12,16 +12,16 @@
 # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 # See the License for the specific language governing permissions and
 # limitations under the License.
-"""Wait operations command."""
+"""Command to wait for an operation to complete."""
 
 from __future__ import absolute_import
 from __future__ import division
 from __future__ import unicode_literals
 
+from googlecloudsdk.api_lib.container.gkemulticloud import operations as op_api_util
 from googlecloudsdk.calliope import base
 from googlecloudsdk.command_lib.container.aws import resource_args
 from googlecloudsdk.command_lib.container.gkemulticloud import endpoint_util
-from googlecloudsdk.command_lib.container.gkemulticloud import operations
 
 _EXAMPLES = """
 To wait for an operation in location ``us-west1'' to complete, run:
@@ -45,9 +45,9 @@ class Describe(base.DescribeCommand):
     with endpoint_util.GkemulticloudEndpointOverride(
         resource_args.ParseOperationResourceArg(args).locationsId,
         self.ReleaseTrack()):
-      op_client = operations.Client(track=self.ReleaseTrack())
+      op_client = op_api_util.OperationsClient()
       op_ref = resource_args.ParseOperationResourceArg(args)
       op_client.Wait(
           op_ref,
           'Waiting for operation {} to complete'.format(op_ref.RelativeName()))
-      return op_client.Describe(op_ref)
+      return op_client.Get(op_ref)
